.. _#hackerfleet IRC Channel: http://webchat.freenode.net/?randomnick=1&channels=hackerfleet&uio=d4

.. faq:

Frequently Asked Questions
==========================


.. general:

General
-------

...  What is Isomer?
   Isomer is an opensource collaborative application platform.

... What platforms does Isomer support?
   We currently test on Debian, various flavours of Python (3.3, 3.4, 3.5, 3.6, pypy)
   It'll probably run on various other platforms as well. E.g. we've made good experiences with Arch Linux.

Got more questions?

* Meet us and chat with us online on the `#hackerfleet IRC Channel`_

.. note:: Please be patient when using IRC, responses might take a few hours!
